package com.facebook.react.common.mapbuffer;

import com.facebook.jni.HybridData;
import java.nio.ByteBuffer;
import java.nio.ByteOrder;
import java.util.Iterator;
import kotlin.UShort;

public class ReadableMapBuffer implements Iterable<MapBufferEntry> {
    private static final int ALIGNMENT = 254;
    private static final int BUCKET_SIZE = 12;
    private static final int HEADER_SIZE = 8;
    private static final int INT_SIZE = 4;
    private static final int TYPE_OFFSET = 2;
    private static final int VALUE_OFFSET = 4;
    ByteBuffer mBuffer = null;
    private int mCount = 0;
    private HybridData mHybridData;

    public enum DataType {
        BOOL,
        INT,
        DOUBLE,
        STRING,
        MAP
    }

    /* access modifiers changed from: private */
    public static int getKeyOffsetForBucketIndex(int i) {
        return (i * 12) + 8;
    }

    private native ByteBuffer importByteBuffer();

    static {
        ReadableMapBufferSoLoader.staticInit();
    }

    private ReadableMapBuffer(HybridData hybridData) {
        this.mHybridData = hybridData;
    }

    private ReadableMapBuffer(ByteBuffer byteBuffer) {
        this.mBuffer = byteBuffer;
        readHeader();
    }

    private int getOffsetForDynamicData() {
        return getKeyOffsetForBucketIndex(this.mCount);
    }

    private int getBucketIndexForKey(int i) {
        importByteBufferAndReadHeader();
        int count = getCount() - 1;
        int i2 = 0;
        while (i2 <= count) {
            int i3 = (i2 + count) >>> 1;
            int readUnsignedShort = readUnsignedShort(getKeyOffsetForBucketIndex(i3));
            if (readUnsignedShort < i) {
                i2 = i3 + 1;
            } else if (readUnsignedShort <= i) {
                return i3;
            } else {
                count = i3 - 1;
            }
        }
        return -1;
    }

    private DataType readDataType(int i) {
        return DataType.values()[readUnsignedShort(getKeyOffsetForBucketIndex(i) + 2)];
    }

    private int getTypedValueOffsetForKey(int i, DataType dataType) {
        int bucketIndexForKey = getBucketIndexForKey(i);
        DataType readDataType = readDataType(bucketIndexForKey);
        if (bucketIndexForKey == -1) {
            throw new IllegalArgumentException("Key not found: " + i);
        } else if (readDataType == dataType) {
            return getKeyOffsetForBucketIndex(bucketIndexForKey) + 4;
        } else {
            throw new IllegalStateException("Expected " + dataType + " for key: " + i + " found " + readDataType.toString() + " instead.");
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private int readUnsignedShort(int i) {
        return this.mBuffer.getShort(i) & UShort.MAX_VALUE;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private double readDoubleValue(int i) {
        return this.mBuffer.getDouble(i);
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private int readIntValue(int i) {
        return this.mBuffer.getInt(i);
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private boolean readBooleanValue(int i) {
        return readIntValue(i) == 1;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private String readStringValue(int i) {
        int offsetForDynamicData = getOffsetForDynamicData() + this.mBuffer.getInt(i);
        int i2 = this.mBuffer.getInt(offsetForDynamicData);
        byte[] bArr = new byte[i2];
        this.mBuffer.position(offsetForDynamicData + 4);
        this.mBuffer.get(bArr, 0, i2);
        return new String(bArr);
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private ReadableMapBuffer readMapBufferValue(int i) {
        int offsetForDynamicData = getOffsetForDynamicData() + this.mBuffer.getInt(i);
        int i2 = this.mBuffer.getInt(offsetForDynamicData);
        byte[] bArr = new byte[i2];
        this.mBuffer.position(offsetForDynamicData + 4);
        this.mBuffer.get(bArr, 0, i2);
        return new ReadableMapBuffer(ByteBuffer.wrap(bArr));
    }

    private void readHeader() {
        if (this.mBuffer.getShort() != ALIGNMENT) {
            this.mBuffer.order(ByteOrder.LITTLE_ENDIAN);
        }
        this.mCount = readUnsignedShort(this.mBuffer.position());
    }

    public boolean hasKey(int i) {
        return getBucketIndexForKey(i) != -1;
    }

    public DataType getType(int i) {
        int bucketIndexForKey = getBucketIndexForKey(i);
        if (bucketIndexForKey != -1) {
            return readDataType(bucketIndexForKey);
        }
        throw new IllegalArgumentException("Key not found: " + i);
    }

    public int getCount() {
        importByteBufferAndReadHeader();
        return this.mCount;
    }

    public int getInt(int i) {
        return readIntValue(getTypedValueOffsetForKey(i, DataType.INT));
    }

    public double getDouble(int i) {
        return readDoubleValue(getTypedValueOffsetForKey(i, DataType.DOUBLE));
    }

    public String getString(int i) {
        return readStringValue(getTypedValueOffsetForKey(i, DataType.STRING));
    }

    public boolean getBoolean(int i) {
        return readBooleanValue(getTypedValueOffsetForKey(i, DataType.BOOL));
    }

    public ReadableMapBuffer getMapBuffer(int i) {
        return readMapBufferValue(getTypedValueOffsetForKey(i, DataType.MAP));
    }

    private ByteBuffer importByteBufferAndReadHeader() {
        ByteBuffer byteBuffer = this.mBuffer;
        if (byteBuffer != null) {
            return byteBuffer;
        }
        this.mBuffer = importByteBuffer();
        readHeader();
        return this.mBuffer;
    }

    private void assertKeyExists(int i, int i2) {
        int readUnsignedShort = readUnsignedShort(getKeyOffsetForBucketIndex(i2));
        if (readUnsignedShort != i) {
            throw new IllegalStateException("Stored key doesn't match parameter - expected: " + i + " - found: " + readUnsignedShort);
        }
    }

    public int hashCode() {
        ByteBuffer importByteBufferAndReadHeader = importByteBufferAndReadHeader();
        importByteBufferAndReadHeader.rewind();
        return importByteBufferAndReadHeader.hashCode();
    }

    public boolean equals(Object obj) {
        if (!(obj instanceof ReadableMapBuffer)) {
            return false;
        }
        ByteBuffer importByteBufferAndReadHeader = importByteBufferAndReadHeader();
        ByteBuffer importByteBufferAndReadHeader2 = ((ReadableMapBuffer) obj).importByteBufferAndReadHeader();
        if (importByteBufferAndReadHeader == importByteBufferAndReadHeader2) {
            return true;
        }
        importByteBufferAndReadHeader.rewind();
        importByteBufferAndReadHeader2.rewind();
        return importByteBufferAndReadHeader.equals(importByteBufferAndReadHeader2);
    }

    @Override // java.lang.Iterable
    public Iterator<MapBufferEntry> iterator() {
        return new Iterator<MapBufferEntry>() {
            /* class com.facebook.react.common.mapbuffer.ReadableMapBuffer.AnonymousClass1 */
            int current = 0;
            final int last;

            {
                this.last = ReadableMapBuffer.this.getCount() - 1;
            }

            public boolean hasNext() {
                return this.current <= this.last;
            }

            @Override // java.util.Iterator
            public MapBufferEntry next() {
                ReadableMapBuffer readableMapBuffer = ReadableMapBuffer.this;
                int i = this.current;
                this.current = i + 1;
                return new MapBufferEntry(ReadableMapBuffer.getKeyOffsetForBucketIndex(i));
            }
        };
    }

    public class MapBufferEntry {
        private final int mBucketOffset;

        private MapBufferEntry(int i) {
            this.mBucketOffset = i;
        }

        private void assertType(DataType dataType) {
            DataType type = getType();
            if (dataType != type) {
                throw new IllegalStateException("Expected " + dataType + " for key: " + getKey() + " found " + type.toString() + " instead.");
            }
        }

        public int getKey() {
            return ReadableMapBuffer.this.readUnsignedShort(this.mBucketOffset);
        }

        public DataType getType() {
            return DataType.values()[ReadableMapBuffer.this.readUnsignedShort(this.mBucketOffset + 2)];
        }

        public double getDouble() {
            assertType(DataType.DOUBLE);
            return ReadableMapBuffer.this.readDoubleValue(this.mBucketOffset + 4);
        }

        public int getInt() {
            assertType(DataType.INT);
            return ReadableMapBuffer.this.readIntValue(this.mBucketOffset + 4);
        }

        public boolean getBoolean() {
            assertType(DataType.BOOL);
            return ReadableMapBuffer.this.readBooleanValue(this.mBucketOffset + 4);
        }

        public String getString() {
            assertType(DataType.STRING);
            return ReadableMapBuffer.this.readStringValue(this.mBucketOffset + 4);
        }

        public ReadableMapBuffer getReadableMapBuffer() {
            assertType(DataType.MAP);
            return ReadableMapBuffer.this.readMapBufferValue(this.mBucketOffset + 4);
        }
    }
}
