package com.facebook.react.views.text;

import android.content.Context;
import android.os.Build;
import android.text.BoringLayout;
import android.text.Layout;
import android.text.Spannable;
import android.text.SpannableStringBuilder;
import android.text.StaticLayout;
import android.text.TextPaint;
import android.util.LruCache;
import com.facebook.react.bridge.ReactNoCrashSoftException;
import com.facebook.react.bridge.ReactSoftExceptionLogger;
import com.facebook.react.bridge.ReadableArray;
import com.facebook.react.bridge.ReadableMap;
import com.facebook.react.bridge.ReadableNativeMap;
import com.facebook.react.bridge.WritableArray;
import com.facebook.react.uimanager.PixelUtil;
import com.facebook.react.uimanager.ReactAccessibilityDelegate;
import com.facebook.react.uimanager.ReactStylesDiffMap;
import com.facebook.react.uimanager.ViewProps;
import com.facebook.yoga.YogaConstants;
import com.facebook.yoga.YogaMeasureMode;
import com.facebook.yoga.YogaMeasureOutput;
import java.util.ArrayList;
import java.util.List;
import java.util.concurrent.ConcurrentHashMap;

public class TextLayoutManager {
    private static final boolean DEFAULT_INCLUDE_FONT_PADDING = true;
    private static final boolean ENABLE_MEASURE_LOGGING = false;
    private static final String HYPHENATION_FREQUENCY_KEY = "android_hyphenationFrequency";
    private static final String INCLUDE_FONT_PADDING_KEY = "includeFontPadding";
    private static final String INLINE_VIEW_PLACEHOLDER = "0";
    private static final String MAXIMUM_NUMBER_OF_LINES_KEY = "maximumNumberOfLines";
    private static final String TAG = "TextLayoutManager";
    private static final String TEXT_BREAK_STRATEGY_KEY = "textBreakStrategy";
    private static final LruCache<ReadableNativeMap, Spannable> sSpannableCache = new LruCache<>(100);
    private static final Object sSpannableCacheLock = new Object();
    private static final ConcurrentHashMap<Integer, Spannable> sTagToSpannableCache = new ConcurrentHashMap<>();
    private static final TextPaint sTextPaintInstance = new TextPaint(1);
    private static final int spannableCacheSize = 100;

    public static boolean isRTL(ReadableMap readableMap) {
        ReadableArray array = readableMap.getArray("fragments");
        if (array.size() <= 0 || TextAttributeProps.getLayoutDirection(array.getMap(0).getMap("textAttributes").getString(ViewProps.LAYOUT_DIRECTION)) != 1) {
            return false;
        }
        return true;
    }

    public static void setCachedSpannabledForTag(int i, Spannable spannable) {
        sTagToSpannableCache.put(Integer.valueOf(i), spannable);
    }

    public static void deleteCachedSpannableForTag(int i) {
        sTagToSpannableCache.remove(Integer.valueOf(i));
    }

    private static void buildSpannableFromFragment(Context context, ReadableArray readableArray, SpannableStringBuilder spannableStringBuilder, List<SetSpanOperation> list) {
        int i;
        int i2 = 0;
        for (int size = readableArray.size(); i2 < size; size = i) {
            ReadableMap map = readableArray.getMap(i2);
            int length = spannableStringBuilder.length();
            TextAttributeProps fromReadableMap = TextAttributeProps.fromReadableMap(new ReactStylesDiffMap(map.getMap("textAttributes")));
            spannableStringBuilder.append((CharSequence) TextTransform.apply(map.getString("string"), fromReadableMap.mTextTransform));
            int length2 = spannableStringBuilder.length();
            int i3 = map.hasKey("reactTag") ? map.getInt("reactTag") : -1;
            if (map.hasKey(ViewProps.IS_ATTACHMENT) && map.getBoolean(ViewProps.IS_ATTACHMENT)) {
                list.add(new SetSpanOperation(spannableStringBuilder.length() - 1, spannableStringBuilder.length(), new TextInlineViewPlaceholderSpan(i3, (int) PixelUtil.toPixelFromSP(map.getDouble("width")), (int) PixelUtil.toPixelFromSP(map.getDouble("height")))));
            } else if (length2 >= length) {
                if (ReactAccessibilityDelegate.AccessibilityRole.LINK.equals(fromReadableMap.mAccessibilityRole)) {
                    list.add(new SetSpanOperation(length, length2, new ReactClickableSpan(i3, fromReadableMap.mColor)));
                } else if (fromReadableMap.mIsColorSet) {
                    list.add(new SetSpanOperation(length, length2, new ReactForegroundColorSpan(fromReadableMap.mColor)));
                }
                if (fromReadableMap.mIsBackgroundColorSet) {
                    list.add(new SetSpanOperation(length, length2, new ReactBackgroundColorSpan(fromReadableMap.mBackgroundColor)));
                }
                if (!Float.isNaN(fromReadableMap.getLetterSpacing())) {
                    list.add(new SetSpanOperation(length, length2, new CustomLetterSpacingSpan(fromReadableMap.getLetterSpacing())));
                }
                list.add(new SetSpanOperation(length, length2, new ReactAbsoluteSizeSpan(fromReadableMap.mFontSize)));
                if (fromReadableMap.mFontStyle == -1 && fromReadableMap.mFontWeight == -1 && fromReadableMap.mFontFamily == null) {
                    i = size;
                } else {
                    i = size;
                    list.add(new SetSpanOperation(length, length2, new CustomStyleSpan(fromReadableMap.mFontStyle, fromReadableMap.mFontWeight, fromReadableMap.mFontFeatureSettings, fromReadableMap.mFontFamily, context.getAssets())));
                }
                if (fromReadableMap.mIsUnderlineTextDecorationSet) {
                    list.add(new SetSpanOperation(length, length2, new ReactUnderlineSpan()));
                }
                if (fromReadableMap.mIsLineThroughTextDecorationSet) {
                    list.add(new SetSpanOperation(length, length2, new ReactStrikethroughSpan()));
                }
                if (!(fromReadableMap.mTextShadowOffsetDx == 0.0f && fromReadableMap.mTextShadowOffsetDy == 0.0f)) {
                    list.add(new SetSpanOperation(length, length2, new ShadowStyleSpan(fromReadableMap.mTextShadowOffsetDx, fromReadableMap.mTextShadowOffsetDy, fromReadableMap.mTextShadowRadius, fromReadableMap.mTextShadowColor)));
                }
                if (!Float.isNaN(fromReadableMap.getEffectiveLineHeight())) {
                    list.add(new SetSpanOperation(length, length2, new CustomLineHeightSpan(fromReadableMap.getEffectiveLineHeight())));
                }
                list.add(new SetSpanOperation(length, length2, new ReactTagSpan(i3)));
                i2++;
            }
            i = size;
            i2++;
        }
    }

    public static Spannable getOrCreateSpannableForText(Context context, ReadableMap readableMap, ReactTextViewManagerCallback reactTextViewManagerCallback) {
        Object obj = sSpannableCacheLock;
        synchronized (obj) {
            LruCache<ReadableNativeMap, Spannable> lruCache = sSpannableCache;
            Spannable spannable = lruCache.get((ReadableNativeMap) readableMap);
            if (spannable != null) {
                return spannable;
            }
            Spannable createSpannableFromAttributedString = createSpannableFromAttributedString(context, readableMap, reactTextViewManagerCallback);
            synchronized (obj) {
                lruCache.put((ReadableNativeMap) readableMap, createSpannableFromAttributedString);
            }
            return createSpannableFromAttributedString;
        }
    }

    private static Spannable createSpannableFromAttributedString(Context context, ReadableMap readableMap, ReactTextViewManagerCallback reactTextViewManagerCallback) {
        SpannableStringBuilder spannableStringBuilder = new SpannableStringBuilder();
        ArrayList<SetSpanOperation> arrayList = new ArrayList();
        buildSpannableFromFragment(context, readableMap.getArray("fragments"), spannableStringBuilder, arrayList);
        int i = 0;
        for (SetSpanOperation setSpanOperation : arrayList) {
            setSpanOperation.execute(spannableStringBuilder, i);
            i++;
        }
        if (reactTextViewManagerCallback != null) {
            reactTextViewManagerCallback.onPostProcessSpannable(spannableStringBuilder);
        }
        return spannableStringBuilder;
    }

    private static Layout createLayout(Spannable spannable, BoringLayout.Metrics metrics, float f, YogaMeasureMode yogaMeasureMode, boolean z, int i, int i2) {
        int i3;
        int length = spannable.length();
        boolean z2 = yogaMeasureMode == YogaMeasureMode.UNDEFINED || f < 0.0f;
        TextPaint textPaint = sTextPaintInstance;
        float desiredWidth = metrics == null ? Layout.getDesiredWidth(spannable, textPaint) : Float.NaN;
        if (metrics == null && (z2 || (!YogaConstants.isUndefined(desiredWidth) && desiredWidth <= f))) {
            int ceil = (int) Math.ceil((double) desiredWidth);
            if (Build.VERSION.SDK_INT < 23) {
                return new StaticLayout(spannable, textPaint, ceil, Layout.Alignment.ALIGN_NORMAL, 1.0f, 0.0f, z);
            }
            return StaticLayout.Builder.obtain(spannable, 0, length, textPaint, ceil).setAlignment(Layout.Alignment.ALIGN_NORMAL).setLineSpacing(0.0f, 1.0f).setIncludePad(z).setBreakStrategy(i).setHyphenationFrequency(i2).build();
        } else if (metrics != null && (z2 || ((float) metrics.width) <= f)) {
            int i4 = metrics.width;
            if (metrics.width < 0) {
                String str = TAG;
                ReactSoftExceptionLogger.logSoftException(str, new ReactNoCrashSoftException("Text width is invalid: " + metrics.width));
                i3 = 0;
            } else {
                i3 = i4;
            }
            return BoringLayout.make(spannable, textPaint, i3, Layout.Alignment.ALIGN_NORMAL, 1.0f, 0.0f, metrics, z);
        } else if (Build.VERSION.SDK_INT < 23) {
            return new StaticLayout(spannable, textPaint, (int) f, Layout.Alignment.ALIGN_NORMAL, 1.0f, 0.0f, z);
        } else {
            StaticLayout.Builder hyphenationFrequency = StaticLayout.Builder.obtain(spannable, 0, length, textPaint, (int) f).setAlignment(Layout.Alignment.ALIGN_NORMAL).setLineSpacing(0.0f, 1.0f).setIncludePad(z).setBreakStrategy(i).setHyphenationFrequency(i2);
            if (Build.VERSION.SDK_INT >= 28) {
                hyphenationFrequency.setUseLineSpacingFromFallbacks(true);
            }
            return hyphenationFrequency.build();
        }
    }

    /* JADX WARNING: Code restructure failed: missing block: B:32:0x00a7, code lost:
        if (r3 > r21) goto L_0x00a9;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:39:0x00bb, code lost:
        if (r1 > r23) goto L_0x00bd;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:73:0x0151, code lost:
        if (r6 != false) goto L_0x0153;
     */
    /* JADX WARNING: Removed duplicated region for block: B:36:0x00af  */
    /* JADX WARNING: Removed duplicated region for block: B:44:0x00c7  */
    public static long measureText(Context context, ReadableMap readableMap, ReadableMap readableMap2, float f, YogaMeasureMode yogaMeasureMode, float f2, YogaMeasureMode yogaMeasureMode2, ReactTextViewManagerCallback reactTextViewManagerCallback, float[] fArr) {
        Spannable spannable;
        int i;
        float f3;
        int i2;
        float f4;
        TextPaint textPaint = sTextPaintInstance;
        if (readableMap.hasKey("cacheId")) {
            int i3 = readableMap.getInt("cacheId");
            ConcurrentHashMap<Integer, Spannable> concurrentHashMap = sTagToSpannableCache;
            if (!concurrentHashMap.containsKey(Integer.valueOf(i3))) {
                return 0;
            }
            spannable = concurrentHashMap.get(Integer.valueOf(i3));
        } else {
            spannable = getOrCreateSpannableForText(context, readableMap, reactTextViewManagerCallback);
        }
        int textBreakStrategy = TextAttributeProps.getTextBreakStrategy(readableMap2.getString("textBreakStrategy"));
        boolean z = readableMap2.hasKey("includeFontPadding") ? readableMap2.getBoolean("includeFontPadding") : true;
        int hyphenationFrequency = TextAttributeProps.getHyphenationFrequency(readableMap2.getString(HYPHENATION_FREQUENCY_KEY));
        if (spannable != null) {
            Layout createLayout = createLayout(spannable, BoringLayout.isBoring(spannable, textPaint), f, yogaMeasureMode, z, textBreakStrategy, hyphenationFrequency);
            int i4 = -1;
            int i5 = readableMap2.hasKey(MAXIMUM_NUMBER_OF_LINES_KEY) ? readableMap2.getInt(MAXIMUM_NUMBER_OF_LINES_KEY) : -1;
            if (i5 == -1 || i5 == 0) {
                i = createLayout.getLineCount();
            } else {
                i = Math.min(i5, createLayout.getLineCount());
            }
            float f5 = 0.0f;
            if (yogaMeasureMode != YogaMeasureMode.EXACTLY) {
                for (int i6 = 0; i6 < i; i6++) {
                    float lineWidth = createLayout.getLineWidth(i6);
                    if (lineWidth > f5) {
                        f5 = lineWidth;
                    }
                }
                if (yogaMeasureMode == YogaMeasureMode.AT_MOST) {
                }
                if (yogaMeasureMode2 != YogaMeasureMode.EXACTLY) {
                    f3 = (float) createLayout.getLineBottom(i - 1);
                    if (yogaMeasureMode2 == YogaMeasureMode.AT_MOST) {
                    }
                    i2 = 0;
                    int i7 = 0;
                    while (i2 < spannable.length()) {
                        int nextSpanTransition = spannable.nextSpanTransition(i2, spannable.length(), TextInlineViewPlaceholderSpan.class);
                        TextInlineViewPlaceholderSpan[] textInlineViewPlaceholderSpanArr = (TextInlineViewPlaceholderSpan[]) spannable.getSpans(i2, nextSpanTransition, TextInlineViewPlaceholderSpan.class);
                        int length = textInlineViewPlaceholderSpanArr.length;
                        int i8 = 0;
                        while (i8 < length) {
                            TextInlineViewPlaceholderSpan textInlineViewPlaceholderSpan = textInlineViewPlaceholderSpanArr[i8];
                            int spanStart = spannable.getSpanStart(textInlineViewPlaceholderSpan);
                            int lineForOffset = createLayout.getLineForOffset(spanStart);
                            if (!(createLayout.getEllipsisCount(lineForOffset) > 0) || spanStart < createLayout.getLineStart(lineForOffset) + createLayout.getEllipsisStart(lineForOffset) || spanStart >= createLayout.getLineEnd(lineForOffset)) {
                                float width = (float) textInlineViewPlaceholderSpan.getWidth();
                                float height = (float) textInlineViewPlaceholderSpan.getHeight();
                                boolean isRtlCharAt = createLayout.isRtlCharAt(spanStart);
                                boolean z2 = createLayout.getParagraphDirection(lineForOffset) == i4;
                                if (spanStart != spannable.length() - 1) {
                                    if (z2 == isRtlCharAt) {
                                        f4 = createLayout.getPrimaryHorizontal(spanStart);
                                    } else {
                                        f4 = createLayout.getSecondaryHorizontal(spanStart);
                                    }
                                    if (z2) {
                                        f4 = f5 - (createLayout.getLineRight(lineForOffset) - f4);
                                    }
                                } else if (z2) {
                                    f4 = f5 - createLayout.getLineWidth(lineForOffset);
                                    int i9 = i7 * 2;
                                    fArr[i9] = PixelUtil.toDIPFromPixel(((float) createLayout.getLineBaseline(lineForOffset)) - height);
                                    fArr[i9 + 1] = PixelUtil.toDIPFromPixel(f4);
                                    i7++;
                                } else {
                                    f4 = createLayout.getLineRight(lineForOffset);
                                }
                                f4 -= width;
                                int i92 = i7 * 2;
                                fArr[i92] = PixelUtil.toDIPFromPixel(((float) createLayout.getLineBaseline(lineForOffset)) - height);
                                fArr[i92 + 1] = PixelUtil.toDIPFromPixel(f4);
                                i7++;
                            }
                            i8++;
                            i4 = -1;
                        }
                        i2 = nextSpanTransition;
                    }
                    return YogaMeasureOutput.make(PixelUtil.toDIPFromPixel(f5), PixelUtil.toDIPFromPixel(f3));
                }
                f3 = f2;
                i2 = 0;
                int i72 = 0;
                while (i2 < spannable.length()) {
                }
                return YogaMeasureOutput.make(PixelUtil.toDIPFromPixel(f5), PixelUtil.toDIPFromPixel(f3));
            }
            f5 = f;
            if (yogaMeasureMode2 != YogaMeasureMode.EXACTLY) {
            }
            f3 = f2;
            i2 = 0;
            int i722 = 0;
            while (i2 < spannable.length()) {
            }
            return YogaMeasureOutput.make(PixelUtil.toDIPFromPixel(f5), PixelUtil.toDIPFromPixel(f3));
        }
        throw new IllegalStateException("Spannable element has not been prepared in onBeforeLayout");
    }

    public static WritableArray measureLines(Context context, ReadableMap readableMap, ReadableMap readableMap2, float f) {
        TextPaint textPaint = sTextPaintInstance;
        Spannable orCreateSpannableForText = getOrCreateSpannableForText(context, readableMap, null);
        return FontMetricsUtil.getFontMetrics(orCreateSpannableForText, createLayout(orCreateSpannableForText, BoringLayout.isBoring(orCreateSpannableForText, textPaint), f, YogaMeasureMode.EXACTLY, readableMap2.hasKey("includeFontPadding") ? readableMap2.getBoolean("includeFontPadding") : true, TextAttributeProps.getTextBreakStrategy(readableMap2.getString("textBreakStrategy")), TextAttributeProps.getTextBreakStrategy(readableMap2.getString(HYPHENATION_FREQUENCY_KEY))), textPaint, context);
    }

    public static class SetSpanOperation {
        protected int end;
        protected int start;
        protected ReactSpan what;

        public SetSpanOperation(int i, int i2, ReactSpan reactSpan) {
            this.start = i;
            this.end = i2;
            this.what = reactSpan;
        }

        public void execute(Spannable spannable, int i) {
            int i2 = this.start;
            spannable.setSpan(this.what, i2, this.end, ((i << 16) & 16711680) | ((i2 == 0 ? 18 : 34) & -16711681));
        }
    }
}
