package com.facebook.react.views.text;

import android.content.Context;
import android.os.Build;
import android.text.BoringLayout;
import android.text.Layout;
import android.text.Spannable;
import android.text.SpannableStringBuilder;
import android.text.StaticLayout;
import android.text.TextPaint;
import android.util.LruCache;
import com.facebook.react.bridge.ReactNoCrashSoftException;
import com.facebook.react.bridge.ReactSoftExceptionLogger;
import com.facebook.react.bridge.WritableArray;
import com.facebook.react.common.mapbuffer.ReadableMapBuffer;
import com.facebook.react.uimanager.PixelUtil;
import com.facebook.react.uimanager.ReactAccessibilityDelegate;
import com.facebook.yoga.YogaConstants;
import com.facebook.yoga.YogaMeasureMode;
import com.facebook.yoga.YogaMeasureOutput;
import java.util.ArrayList;
import java.util.List;
import java.util.concurrent.ConcurrentHashMap;

public class TextLayoutManagerMapBuffer {
    public static final short AS_KEY_CACHE_ID = 3;
    public static final short AS_KEY_FRAGMENTS = 2;
    public static final short AS_KEY_HASH = 0;
    public static final short AS_KEY_STRING = 1;
    private static final boolean DEFAULT_INCLUDE_FONT_PADDING = true;
    private static final boolean ENABLE_MEASURE_LOGGING = false;
    public static final short FR_KEY_HEIGHT = 4;
    public static final short FR_KEY_IS_ATTACHMENT = 2;
    public static final short FR_KEY_REACT_TAG = 1;
    public static final short FR_KEY_STRING = 0;
    public static final short FR_KEY_TEXT_ATTRIBUTES = 5;
    public static final short FR_KEY_WIDTH = 3;
    private static final String INLINE_VIEW_PLACEHOLDER = "0";
    public static final short PA_KEY_ADJUST_FONT_SIZE_TO_FIT = 3;
    public static final short PA_KEY_ELLIPSIZE_MODE = 1;
    public static final short PA_KEY_HYPHENATION_FREQUENCY = 5;
    public static final short PA_KEY_INCLUDE_FONT_PADDING = 4;
    public static final short PA_KEY_MAX_NUMBER_OF_LINES = 0;
    public static final short PA_KEY_TEXT_BREAK_STRATEGY = 2;
    private static final String TAG = "TextLayoutManagerMapBuffer";
    private static final LruCache<ReadableMapBuffer, Spannable> sSpannableCache = new LruCache<>(100);
    private static final Object sSpannableCacheLock = new Object();
    private static final ConcurrentHashMap<Integer, Spannable> sTagToSpannableCache = new ConcurrentHashMap<>();
    private static final TextPaint sTextPaintInstance = new TextPaint(1);
    private static final short spannableCacheSize = 100;

    public static void setCachedSpannabledForTag(int i, Spannable spannable) {
        sTagToSpannableCache.put(Integer.valueOf(i), spannable);
    }

    public static void deleteCachedSpannableForTag(int i) {
        sTagToSpannableCache.remove(Integer.valueOf(i));
    }

    public static boolean isRTL(ReadableMapBuffer readableMapBuffer) {
        ReadableMapBuffer mapBuffer = readableMapBuffer.getMapBuffer(2);
        if (mapBuffer.getCount() != 0 && TextAttributeProps.getLayoutDirection(mapBuffer.getMapBuffer(0).getMapBuffer(5).getString(21)) == 1) {
            return true;
        }
        return false;
    }

    private static void buildSpannableFromFragment(Context context, ReadableMapBuffer readableMapBuffer, SpannableStringBuilder spannableStringBuilder, List<SetSpanOperation> list) {
        int count = readableMapBuffer.getCount();
        for (int i = 0; i < count; i++) {
            ReadableMapBuffer mapBuffer = readableMapBuffer.getMapBuffer(i);
            int length = spannableStringBuilder.length();
            TextAttributeProps fromReadableMapBuffer = TextAttributeProps.fromReadableMapBuffer(mapBuffer.getMapBuffer(5));
            spannableStringBuilder.append((CharSequence) TextTransform.apply(mapBuffer.getString(0), fromReadableMapBuffer.mTextTransform));
            int length2 = spannableStringBuilder.length();
            int i2 = mapBuffer.hasKey(1) ? mapBuffer.getInt(1) : -1;
            if (mapBuffer.hasKey(2) && mapBuffer.getBoolean(2)) {
                list.add(new SetSpanOperation(spannableStringBuilder.length() - 1, spannableStringBuilder.length(), new TextInlineViewPlaceholderSpan(i2, (int) PixelUtil.toPixelFromSP(mapBuffer.getDouble(3)), (int) PixelUtil.toPixelFromSP(mapBuffer.getDouble(4)))));
            } else if (length2 >= length) {
                if (ReactAccessibilityDelegate.AccessibilityRole.LINK.equals(fromReadableMapBuffer.mAccessibilityRole)) {
                    list.add(new SetSpanOperation(length, length2, new ReactClickableSpan(i2, fromReadableMapBuffer.mColor)));
                } else if (fromReadableMapBuffer.mIsColorSet) {
                    list.add(new SetSpanOperation(length, length2, new ReactForegroundColorSpan(fromReadableMapBuffer.mColor)));
                }
                if (fromReadableMapBuffer.mIsBackgroundColorSet) {
                    list.add(new SetSpanOperation(length, length2, new ReactBackgroundColorSpan(fromReadableMapBuffer.mBackgroundColor)));
                }
                if (!Float.isNaN(fromReadableMapBuffer.getLetterSpacing())) {
                    list.add(new SetSpanOperation(length, length2, new CustomLetterSpacingSpan(fromReadableMapBuffer.getLetterSpacing())));
                }
                list.add(new SetSpanOperation(length, length2, new ReactAbsoluteSizeSpan(fromReadableMapBuffer.mFontSize)));
                if (!(fromReadableMapBuffer.mFontStyle == -1 && fromReadableMapBuffer.mFontWeight == -1 && fromReadableMapBuffer.mFontFamily == null)) {
                    list.add(new SetSpanOperation(length, length2, new CustomStyleSpan(fromReadableMapBuffer.mFontStyle, fromReadableMapBuffer.mFontWeight, fromReadableMapBuffer.mFontFeatureSettings, fromReadableMapBuffer.mFontFamily, context.getAssets())));
                }
                if (fromReadableMapBuffer.mIsUnderlineTextDecorationSet) {
                    list.add(new SetSpanOperation(length, length2, new ReactUnderlineSpan()));
                }
                if (fromReadableMapBuffer.mIsLineThroughTextDecorationSet) {
                    list.add(new SetSpanOperation(length, length2, new ReactStrikethroughSpan()));
                }
                if (!(fromReadableMapBuffer.mTextShadowOffsetDx == 0.0f && fromReadableMapBuffer.mTextShadowOffsetDy == 0.0f)) {
                    list.add(new SetSpanOperation(length, length2, new ShadowStyleSpan(fromReadableMapBuffer.mTextShadowOffsetDx, fromReadableMapBuffer.mTextShadowOffsetDy, fromReadableMapBuffer.mTextShadowRadius, fromReadableMapBuffer.mTextShadowColor)));
                }
                if (!Float.isNaN(fromReadableMapBuffer.getEffectiveLineHeight())) {
                    list.add(new SetSpanOperation(length, length2, new CustomLineHeightSpan(fromReadableMapBuffer.getEffectiveLineHeight())));
                }
                list.add(new SetSpanOperation(length, length2, new ReactTagSpan(i2)));
            }
        }
    }

    public static Spannable getOrCreateSpannableForText(Context context, ReadableMapBuffer readableMapBuffer, ReactTextViewManagerCallback reactTextViewManagerCallback) {
        Object obj = sSpannableCacheLock;
        synchronized (obj) {
            LruCache<ReadableMapBuffer, Spannable> lruCache = sSpannableCache;
            Spannable spannable = lruCache.get(readableMapBuffer);
            if (spannable != null) {
                return spannable;
            }
            Spannable createSpannableFromAttributedString = createSpannableFromAttributedString(context, readableMapBuffer, reactTextViewManagerCallback);
            synchronized (obj) {
                lruCache.put(readableMapBuffer, createSpannableFromAttributedString);
            }
            return createSpannableFromAttributedString;
        }
    }

    private static Spannable createSpannableFromAttributedString(Context context, ReadableMapBuffer readableMapBuffer, ReactTextViewManagerCallback reactTextViewManagerCallback) {
        SpannableStringBuilder spannableStringBuilder = new SpannableStringBuilder();
        ArrayList<SetSpanOperation> arrayList = new ArrayList();
        buildSpannableFromFragment(context, readableMapBuffer.getMapBuffer(2), spannableStringBuilder, arrayList);
        int i = 0;
        for (SetSpanOperation setSpanOperation : arrayList) {
            setSpanOperation.execute(spannableStringBuilder, i);
            i++;
        }
        if (reactTextViewManagerCallback != null) {
            reactTextViewManagerCallback.onPostProcessSpannable(spannableStringBuilder);
        }
        return spannableStringBuilder;
    }

    private static Layout createLayout(Spannable spannable, BoringLayout.Metrics metrics, float f, YogaMeasureMode yogaMeasureMode, boolean z, int i, int i2) {
        int i3;
        int length = spannable.length();
        boolean z2 = yogaMeasureMode == YogaMeasureMode.UNDEFINED || f < 0.0f;
        TextPaint textPaint = sTextPaintInstance;
        float desiredWidth = metrics == null ? Layout.getDesiredWidth(spannable, textPaint) : Float.NaN;
        if (metrics == null && (z2 || (!YogaConstants.isUndefined(desiredWidth) && desiredWidth <= f))) {
            int ceil = (int) Math.ceil((double) desiredWidth);
            if (Build.VERSION.SDK_INT < 23) {
                return new StaticLayout(spannable, textPaint, ceil, Layout.Alignment.ALIGN_NORMAL, 1.0f, 0.0f, z);
            }
            return StaticLayout.Builder.obtain(spannable, 0, length, textPaint, ceil).setAlignment(Layout.Alignment.ALIGN_NORMAL).setLineSpacing(0.0f, 1.0f).setIncludePad(z).setBreakStrategy(i).setHyphenationFrequency(i2).build();
        } else if (metrics != null && (z2 || ((float) metrics.width) <= f)) {
            int i4 = metrics.width;
            if (metrics.width < 0) {
                String str = TAG;
                ReactSoftExceptionLogger.logSoftException(str, new ReactNoCrashSoftException("Text width is invalid: " + metrics.width));
                i3 = 0;
            } else {
                i3 = i4;
            }
            return BoringLayout.make(spannable, textPaint, i3, Layout.Alignment.ALIGN_NORMAL, 1.0f, 0.0f, metrics, z);
        } else if (Build.VERSION.SDK_INT < 23) {
            return new StaticLayout(spannable, textPaint, (int) f, Layout.Alignment.ALIGN_NORMAL, 1.0f, 0.0f, z);
        } else {
            StaticLayout.Builder hyphenationFrequency = StaticLayout.Builder.obtain(spannable, 0, length, textPaint, (int) f).setAlignment(Layout.Alignment.ALIGN_NORMAL).setLineSpacing(0.0f, 1.0f).setIncludePad(z).setBreakStrategy(i).setHyphenationFrequency(i2);
            if (Build.VERSION.SDK_INT >= 28) {
                hyphenationFrequency.setUseLineSpacingFromFallbacks(true);
            }
            return hyphenationFrequency.build();
        }
    }

    /* JADX WARNING: Code restructure failed: missing block: B:38:0x00ad, code lost:
        if (r12 > r21) goto L_0x00af;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:45:0x00c1, code lost:
        if (r1 > r23) goto L_0x00c3;
     */
    /* JADX WARNING: Removed duplicated region for block: B:42:0x00b5  */
    /* JADX WARNING: Removed duplicated region for block: B:50:0x00cd  */
    public static long measureText(Context context, ReadableMapBuffer readableMapBuffer, ReadableMapBuffer readableMapBuffer2, float f, YogaMeasureMode yogaMeasureMode, float f2, YogaMeasureMode yogaMeasureMode2, ReactTextViewManagerCallback reactTextViewManagerCallback, float[] fArr) {
        Spannable spannable;
        int i;
        float f3;
        int i2;
        float f4;
        float f5;
        TextPaint textPaint = sTextPaintInstance;
        if (readableMapBuffer.hasKey(3)) {
            int i3 = readableMapBuffer.getInt(3);
            ConcurrentHashMap<Integer, Spannable> concurrentHashMap = sTagToSpannableCache;
            if (!concurrentHashMap.containsKey(Integer.valueOf(i3))) {
                return 0;
            }
            spannable = concurrentHashMap.get(Integer.valueOf(i3));
        } else {
            spannable = getOrCreateSpannableForText(context, readableMapBuffer, reactTextViewManagerCallback);
        }
        int textBreakStrategy = TextAttributeProps.getTextBreakStrategy(readableMapBuffer2.getString(2));
        boolean z = readableMapBuffer2.hasKey(4) ? readableMapBuffer2.getBoolean(4) : true;
        int textBreakStrategy2 = TextAttributeProps.getTextBreakStrategy(readableMapBuffer2.getString(5));
        if (spannable != null) {
            BoringLayout.Metrics isBoring = BoringLayout.isBoring(spannable, textPaint);
            if (isBoring == null) {
                Layout.getDesiredWidth(spannable, textPaint);
            }
            float f6 = 0.0f;
            if (yogaMeasureMode != YogaMeasureMode.UNDEFINED) {
                int i4 = (f > 0.0f ? 1 : (f == 0.0f ? 0 : -1));
            }
            Layout createLayout = createLayout(spannable, isBoring, f, yogaMeasureMode, z, textBreakStrategy, textBreakStrategy2);
            int i5 = -1;
            int i6 = readableMapBuffer2.hasKey(0) ? readableMapBuffer2.getInt(0) : -1;
            if (i6 == -1 || i6 == 0) {
                i = createLayout.getLineCount();
            } else {
                i = Math.min(i6, createLayout.getLineCount());
            }
            if (yogaMeasureMode != YogaMeasureMode.EXACTLY) {
                for (int i7 = 0; i7 < i; i7++) {
                    float lineWidth = createLayout.getLineWidth(i7);
                    if (lineWidth > f6) {
                        f6 = lineWidth;
                    }
                }
                if (yogaMeasureMode == YogaMeasureMode.AT_MOST) {
                }
                if (yogaMeasureMode2 != YogaMeasureMode.EXACTLY) {
                    f3 = (float) createLayout.getLineBottom(i - 1);
                    if (yogaMeasureMode2 == YogaMeasureMode.AT_MOST) {
                    }
                    i2 = 0;
                    int i8 = 0;
                    while (i2 < spannable.length()) {
                        int nextSpanTransition = spannable.nextSpanTransition(i2, spannable.length(), TextInlineViewPlaceholderSpan.class);
                        TextInlineViewPlaceholderSpan[] textInlineViewPlaceholderSpanArr = (TextInlineViewPlaceholderSpan[]) spannable.getSpans(i2, nextSpanTransition, TextInlineViewPlaceholderSpan.class);
                        int length = textInlineViewPlaceholderSpanArr.length;
                        int i9 = 0;
                        while (i9 < length) {
                            TextInlineViewPlaceholderSpan textInlineViewPlaceholderSpan = textInlineViewPlaceholderSpanArr[i9];
                            int spanStart = spannable.getSpanStart(textInlineViewPlaceholderSpan);
                            int lineForOffset = createLayout.getLineForOffset(spanStart);
                            if (!(createLayout.getEllipsisCount(lineForOffset) > 0) || spanStart < createLayout.getLineStart(lineForOffset) + createLayout.getEllipsisStart(lineForOffset) || spanStart >= createLayout.getLineEnd(lineForOffset)) {
                                float width = (float) textInlineViewPlaceholderSpan.getWidth();
                                float height = (float) textInlineViewPlaceholderSpan.getHeight();
                                boolean isRtlCharAt = createLayout.isRtlCharAt(spanStart);
                                boolean z2 = createLayout.getParagraphDirection(lineForOffset) == i5;
                                if (spanStart == spannable.length() - 1) {
                                    f4 = z2 ? f6 - createLayout.getLineWidth(lineForOffset) : createLayout.getLineRight(lineForOffset) - width;
                                } else {
                                    if (z2 == isRtlCharAt) {
                                        f5 = createLayout.getPrimaryHorizontal(spanStart);
                                    } else {
                                        f5 = createLayout.getSecondaryHorizontal(spanStart);
                                    }
                                    if (z2) {
                                        f5 = f6 - (createLayout.getLineRight(lineForOffset) - f5);
                                    }
                                    f4 = isRtlCharAt ? f5 - width : f5;
                                }
                                float lineBaseline = ((float) createLayout.getLineBaseline(lineForOffset)) - height;
                                int i10 = i8 * 2;
                                fArr[i10] = PixelUtil.toDIPFromPixel(lineBaseline);
                                fArr[i10 + 1] = PixelUtil.toDIPFromPixel(f4);
                                i8++;
                            }
                            i9++;
                            i5 = -1;
                        }
                        i2 = nextSpanTransition;
                    }
                    return YogaMeasureOutput.make(PixelUtil.toDIPFromPixel(f6), PixelUtil.toDIPFromPixel(f3));
                }
                f3 = f2;
                i2 = 0;
                int i82 = 0;
                while (i2 < spannable.length()) {
                }
                return YogaMeasureOutput.make(PixelUtil.toDIPFromPixel(f6), PixelUtil.toDIPFromPixel(f3));
            }
            f6 = f;
            if (yogaMeasureMode2 != YogaMeasureMode.EXACTLY) {
            }
            f3 = f2;
            i2 = 0;
            int i822 = 0;
            while (i2 < spannable.length()) {
            }
            return YogaMeasureOutput.make(PixelUtil.toDIPFromPixel(f6), PixelUtil.toDIPFromPixel(f3));
        }
        throw new IllegalStateException("Spannable element has not been prepared in onBeforeLayout");
    }

    public static WritableArray measureLines(Context context, ReadableMapBuffer readableMapBuffer, ReadableMapBuffer readableMapBuffer2, float f) {
        TextPaint textPaint = sTextPaintInstance;
        Spannable orCreateSpannableForText = getOrCreateSpannableForText(context, readableMapBuffer, null);
        return FontMetricsUtil.getFontMetrics(orCreateSpannableForText, createLayout(orCreateSpannableForText, BoringLayout.isBoring(orCreateSpannableForText, textPaint), f, YogaMeasureMode.EXACTLY, readableMapBuffer2.hasKey(4) ? readableMapBuffer2.getBoolean(4) : true, TextAttributeProps.getTextBreakStrategy(readableMapBuffer2.getString(2)), TextAttributeProps.getTextBreakStrategy(readableMapBuffer2.getString(5))), textPaint, context);
    }

    public static class SetSpanOperation {
        protected int end;
        protected int start;
        protected ReactSpan what;

        public SetSpanOperation(int i, int i2, ReactSpan reactSpan) {
            this.start = i;
            this.end = i2;
            this.what = reactSpan;
        }

        public void execute(Spannable spannable, int i) {
            int i2 = this.start;
            spannable.setSpan(this.what, i2, this.end, ((i << 16) & 16711680) | ((i2 == 0 ? 18 : 34) & -16711681));
        }
    }
}
