package com.facebook.soloader;

import android.content.Context;
import android.os.Build;
import android.os.StrictMode;
import android.text.TextUtils;
import android.util.Log;
import com.facebook.soloader.SoLoader;
import java.io.File;
import java.io.IOException;
import java.util.Collections;
import java.util.Enumeration;
import java.util.HashSet;
import java.util.Set;
import java.util.zip.ZipEntry;
import java.util.zip.ZipFile;
import javax.annotation.Nullable;

public class DirectApkSoSource extends SoSource {
    private final File mApkFile;
    @Nullable
    private final String mDirectApkLdPath;
    private final Set<String> mLibsInApk;

    public DirectApkSoSource(Context context) {
        this.mLibsInApk = Collections.synchronizedSet(new HashSet());
        this.mDirectApkLdPath = getDirectApkLdPath("");
        this.mApkFile = new File(context.getApplicationInfo().sourceDir);
    }

    public DirectApkSoSource(File file) {
        this.mLibsInApk = Collections.synchronizedSet(new HashSet());
        this.mDirectApkLdPath = getDirectApkLdPath(SysUtil.getBaseName(file.getName()));
        this.mApkFile = file;
    }

    @Override // com.facebook.soloader.SoSource
    public int loadLibrary(String str, int i, StrictMode.ThreadPolicy threadPolicy) throws IOException {
        if (SoLoader.sSoFileLoader == null) {
            throw new IllegalStateException("SoLoader.init() not yet called");
        } else if (!this.mLibsInApk.contains(str) || TextUtils.isEmpty(this.mDirectApkLdPath)) {
            Log.d("SoLoader", str + " not found on " + this.mDirectApkLdPath);
            return 0;
        } else {
            loadDependencies(str, i, threadPolicy);
            int i2 = i | 4;
            try {
                SoFileLoader soFileLoader = SoLoader.sSoFileLoader;
                soFileLoader.load(this.mDirectApkLdPath + File.separator + str, i2);
                Log.d("SoLoader", str + " found on DirectAPKSoSource: " + i2);
                return 1;
            } catch (UnsatisfiedLinkError e) {
                Log.w("SoLoader", str + " not found on DirectAPKSoSource: " + i2, e);
                return 0;
            }
        }
    }

    @Override // com.facebook.soloader.SoSource
    public File unpackLibrary(String str) throws IOException {
        throw new UnsupportedOperationException("DirectAPKSoSource doesn't support unpackLibrary");
    }

    @Nullable
    private static String getDirectApkLdPath(String str) {
        String classLoaderLdLoadLibrary = Build.VERSION.SDK_INT >= 14 ? SoLoader.Api14Utils.getClassLoaderLdLoadLibrary() : null;
        if (classLoaderLdLoadLibrary != null) {
            String[] split = classLoaderLdLoadLibrary.split(":");
            for (String str2 : split) {
                if (str2.contains(str + ".apk!/")) {
                    return str2;
                }
            }
        }
        return null;
    }

    private static String[] getDependencies(String str, ElfByteChannel elfByteChannel) throws IOException {
        if (SoLoader.SYSTRACE_LIBRARY_LOADING) {
            Api18TraceUtils.beginTraceSection("SoLoader.getElfDependencies[", str, "]");
        }
        try {
            return NativeDeps.getDependencies(str, elfByteChannel);
        } finally {
            if (SoLoader.SYSTRACE_LIBRARY_LOADING) {
                Api18TraceUtils.endSection();
            }
        }
    }

    private void loadDependencies(String str, int i, StrictMode.ThreadPolicy threadPolicy) throws IOException {
        ZipFile zipFile = new ZipFile(this.mApkFile);
        try {
            Enumeration<? extends ZipEntry> entries = zipFile.entries();
            while (true) {
                if (!entries.hasMoreElements()) {
                    break;
                }
                ZipEntry zipEntry = (ZipEntry) entries.nextElement();
                if (zipEntry != null) {
                    if (zipEntry.getName().endsWith("/" + str)) {
                        ElfZipFileChannel elfZipFileChannel = new ElfZipFileChannel(zipFile, zipEntry);
                        try {
                            String[] dependencies = getDependencies(str, elfZipFileChannel);
                            for (String str2 : dependencies) {
                                if (!this.mLibsInApk.contains(str2)) {
                                    if (!str2.startsWith("/")) {
                                        SoLoader.loadLibraryBySoName(str2, i | 1, threadPolicy);
                                    }
                                }
                            }
                            elfZipFileChannel.close();
                        } catch (Throwable th) {
                            th.addSuppressed(th);
                        }
                    }
                }
            }
            zipFile.close();
            return;
            throw th;
            throw th;
        } catch (Throwable th2) {
            th.addSuppressed(th2);
        }
    }

    /* access modifiers changed from: protected */
    @Override // com.facebook.soloader.SoSource
    public void prepare(int i) throws IOException {
        int indexOf;
        int i2;
        String substring = (TextUtils.isEmpty(this.mDirectApkLdPath) || (indexOf = this.mDirectApkLdPath.indexOf(33)) < 0 || (i2 = indexOf + 2) >= this.mDirectApkLdPath.length()) ? null : this.mDirectApkLdPath.substring(i2);
        if (substring != null) {
            ZipFile zipFile = new ZipFile(this.mApkFile);
            try {
                Enumeration<? extends ZipEntry> entries = zipFile.entries();
                while (entries.hasMoreElements()) {
                    ZipEntry zipEntry = (ZipEntry) entries.nextElement();
                    if (zipEntry != null && zipEntry.getName().startsWith(substring) && zipEntry.getName().endsWith(".so") && zipEntry.getMethod() == 0) {
                        this.mLibsInApk.add(zipEntry.getName().substring(substring.length() + 1));
                    }
                }
                zipFile.close();
                return;
            } catch (Throwable th) {
                th.addSuppressed(th);
            }
        } else {
            return;
        }
        throw th;
    }

    @Override // com.facebook.soloader.SoSource
    public String toString() {
        return getClass().getName() + "[root = " + this.mDirectApkLdPath + ']';
    }
}
