package net.squirrel.httpsplugin.utils;

import android.util.Log;
import com.facebook.react.bridge.Arguments;
import com.facebook.react.bridge.WritableMap;
import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.OutputStream;
import java.net.URL;
import java.security.KeyManagementException;
import java.security.KeyStoreException;
import java.security.NoSuchAlgorithmException;
import java.security.cert.CertificateException;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import javax.net.ssl.HostnameVerifier;
import javax.net.ssl.HttpsURLConnection;
import javax.net.ssl.SSLSession;
import net.squirrel.httpsplugin.models.HttpRequest;
import net.squirrel.httpsplugin.models.HttpResponse;
import org.json.JSONException;
import org.json.JSONObject;

public class HttpUtil {
    private static final String DEFAULT_CONTENT_TYPE = "application/json";

    private String getResponseBody(InputStream inputStream) throws IOException {
        BufferedReader bufferedReader = new BufferedReader(new InputStreamReader(inputStream));
        StringBuilder sb = new StringBuilder();
        while (true) {
            String readLine = bufferedReader.readLine();
            if (readLine != null) {
                sb.append(readLine);
            } else {
                bufferedReader.close();
                return sb.toString();
            }
        }
    }

    private WritableMap getResponseHeaders(HttpsURLConnection httpsURLConnection) {
        WritableMap createMap = Arguments.createMap();
        for (Map.Entry entry : httpsURLConnection.getHeaderFields().entrySet()) {
            if (entry.getKey() != null) {
                createMap.putString((String) entry.getKey(), (String) ((List) entry.getValue()).get(0));
            }
        }
        return createMap;
    }

    private HttpsURLConnection prepareRequestHeaders(HttpsURLConnection httpsURLConnection, JSONObject jSONObject) throws JSONException {
        httpsURLConnection.setRequestProperty("Content-Type", DEFAULT_CONTENT_TYPE);
        httpsURLConnection.setRequestProperty("Accept", DEFAULT_CONTENT_TYPE);
        if (jSONObject != null) {
            Iterator<String> keys = jSONObject.keys();
            while (keys.hasNext()) {
                String next = keys.next();
                httpsURLConnection.setRequestProperty(next, jSONObject.get(next).toString());
            }
        }
        return httpsURLConnection;
    }

    private HttpsURLConnection prepareRequest(HttpRequest httpRequest) throws IOException, KeyStoreException, CertificateException, KeyManagementException, NoSuchAlgorithmException, JSONException {
        URL url = new URL(httpRequest.endpoint);
        String upperCase = httpRequest.method.toUpperCase();
        HttpsURLConnection httpsURLConnection = (HttpsURLConnection) url.openConnection();
        if (httpRequest.endpoint != null && httpRequest.endpoint.startsWith("https")) {
            httpsURLConnection.setSSLSocketFactory(SSLContextUtil.getInstance(httpRequest.truststore, httpRequest.keystore, httpRequest.storeType, httpRequest.storePassword).getContext().getSocketFactory());
            httpsURLConnection.setHostnameVerifier(new HostnameVerifier() {
                /* class net.squirrel.httpsplugin.utils.HttpUtil.AnonymousClass1 */

                public boolean verify(String str, SSLSession sSLSession) {
                    Log.d("==HostnameVerifier==", str);
                    return true;
                }
            });
        }
        httpsURLConnection.setRequestMethod(upperCase);
        HttpsURLConnection prepareRequestHeaders = prepareRequestHeaders(httpsURLConnection, httpRequest.headers);
        prepareRequestHeaders.setRequestProperty("Accept-Charset", "UTF-8");
        prepareRequestHeaders.setAllowUserInteraction(false);
        prepareRequestHeaders.setConnectTimeout(httpRequest.timeout);
        prepareRequestHeaders.setReadTimeout(httpRequest.timeout);
        if (httpRequest.body != null && (upperCase.equals("POST") || upperCase.equals("PUT") || upperCase.equals("DELETE"))) {
            prepareRequestHeaders.setRequestProperty("Content-length", httpRequest.body.getBytes().length + "");
            prepareRequestHeaders.setDoInput(true);
            prepareRequestHeaders.setDoOutput(true);
            prepareRequestHeaders.setUseCaches(false);
            OutputStream outputStream = prepareRequestHeaders.getOutputStream();
            outputStream.write(httpRequest.body.getBytes("UTF-8"));
            outputStream.close();
        }
        return prepareRequestHeaders;
    }

    private InputStream prepareResponseStream(HttpsURLConnection httpsURLConnection) throws IOException {
        try {
            return httpsURLConnection.getInputStream();
        } catch (IOException unused) {
            return httpsURLConnection.getErrorStream();
        }
    }

    public HttpResponse sendHttpRequest(HttpRequest httpRequest) throws IOException, KeyStoreException, CertificateException, KeyManagementException, NoSuchAlgorithmException, JSONException {
        HttpResponse httpResponse = new HttpResponse();
        InputStream inputStream = null;
        try {
            HttpsURLConnection prepareRequest = prepareRequest(httpRequest);
            prepareRequest.connect();
            int responseCode = prepareRequest.getResponseCode();
            String responseMessage = prepareRequest.getResponseMessage();
            inputStream = prepareResponseStream(prepareRequest);
            httpResponse.statusCode = responseCode;
            httpResponse.statusText = responseMessage;
            httpResponse.bodyString = getResponseBody(inputStream);
            httpResponse.headers = getResponseHeaders(prepareRequest);
            return httpResponse;
        } finally {
            if (inputStream != null) {
                inputStream.close();
            }
        }
    }
}
