package org.matrix.olm;

import android.text.TextUtils;
import android.util.Log;
import java.io.IOException;
import java.io.ObjectInputStream;
import java.io.ObjectOutputStream;
import java.io.Serializable;
import java.util.Arrays;
import java.util.Map;
import org.json.JSONObject;

public class OlmAccount extends CommonSerializeUtils implements Serializable {
    public static final String JSON_KEY_FINGER_PRINT_KEY = "ed25519";
    public static final String JSON_KEY_IDENTITY_KEY = "curve25519";
    public static final String JSON_KEY_ONE_TIME_KEY = "curve25519";
    private static final String LOG_TAG = "OlmAccount";
    private static final long serialVersionUID = 3497486121598434824L;
    private transient long mNativeId;

    private native long createNewAccountJni();

    private native long deserializeJni(byte[] bArr, byte[] bArr2);

    private native byte[] fallbackKeyJni();

    private native void generateFallbackKeyJni();

    private native void generateOneTimeKeysJni(int i);

    private native byte[] identityKeysJni();

    private native void markOneTimeKeysAsPublishedJni();

    private native long maxOneTimeKeysJni();

    private native byte[] oneTimeKeysJni();

    private native void releaseAccountJni();

    private native void removeOneTimeKeysJni(long j);

    private native byte[] serializeJni(byte[] bArr);

    private native byte[] signMessageJni(byte[] bArr);

    public OlmAccount() throws OlmException {
        try {
            this.mNativeId = createNewAccountJni();
        } catch (Exception e) {
            throw new OlmException(10, e.getMessage());
        }
    }

    /* access modifiers changed from: package-private */
    public long getOlmAccountId() {
        return this.mNativeId;
    }

    public void releaseAccount() {
        if (0 != this.mNativeId) {
            releaseAccountJni();
        }
        this.mNativeId = 0;
    }

    public boolean isReleased() {
        return 0 == this.mNativeId;
    }

    public Map<String, String> identityKeys() throws OlmException {
        JSONObject jSONObject;
        try {
            byte[] identityKeysJni = identityKeysJni();
            if (identityKeysJni != null) {
                try {
                    jSONObject = new JSONObject(new String(identityKeysJni, "UTF-8"));
                } catch (Exception e) {
                    Log.e(LOG_TAG, "## identityKeys(): Exception - Msg=" + e.getMessage());
                }
            } else {
                Log.e(LOG_TAG, "## identityKeys(): Failure - identityKeysJni()=null");
                jSONObject = null;
            }
            return OlmUtility.toStringMap(jSONObject);
        } catch (Exception e2) {
            Log.e(LOG_TAG, "## identityKeys(): Failure - " + e2.getMessage());
            throw new OlmException(102, e2.getMessage());
        }
    }

    public long maxOneTimeKeys() {
        return maxOneTimeKeysJni();
    }

    public void generateOneTimeKeys(int i) throws OlmException {
        try {
            generateOneTimeKeysJni(i);
        } catch (Exception e) {
            throw new OlmException(103, e.getMessage());
        }
    }

    public Map<String, Map<String, String>> oneTimeKeys() throws OlmException {
        JSONObject jSONObject;
        try {
            byte[] oneTimeKeysJni = oneTimeKeysJni();
            if (oneTimeKeysJni != null) {
                try {
                    jSONObject = new JSONObject(new String(oneTimeKeysJni, "UTF-8"));
                } catch (Exception e) {
                    Log.e(LOG_TAG, "## oneTimeKeys(): Exception - Msg=" + e.getMessage());
                }
            } else {
                Log.e(LOG_TAG, "## oneTimeKeys(): Failure - identityKeysJni()=null");
                jSONObject = null;
            }
            return OlmUtility.toStringMapMap(jSONObject);
        } catch (Exception e2) {
            throw new OlmException(104, e2.getMessage());
        }
    }

    public void removeOneTimeKeys(OlmSession olmSession) throws OlmException {
        if (olmSession != null) {
            try {
                removeOneTimeKeysJni(olmSession.getOlmSessionId());
            } catch (Exception e) {
                throw new OlmException(105, e.getMessage());
            }
        }
    }

    public void markOneTimeKeysAsPublished() throws OlmException {
        try {
            markOneTimeKeysAsPublishedJni();
        } catch (Exception e) {
            throw new OlmException(106, e.getMessage());
        }
    }

    /* JADX WARNING: Removed duplicated region for block: B:22:0x0035  */
    public String signMessage(String str) throws OlmException {
        Throwable th;
        Exception e;
        String str2 = null;
        str2 = null;
        str2 = null;
        byte[] bArr = null;
        if (str != null) {
            try {
                byte[] bytes = str.getBytes("UTF-8");
                if (bytes != null) {
                    try {
                        byte[] signMessageJni = signMessageJni(bytes);
                        if (signMessageJni != null) {
                            str2 = new String(signMessageJni, "UTF-8");
                        }
                    } catch (Exception e2) {
                        e = e2;
                        bArr = bytes;
                        try {
                            throw new OlmException(107, e.getMessage());
                        } catch (Throwable th2) {
                            th = th2;
                            if (bArr != null) {
                                Arrays.fill(bArr, (byte) 0);
                            }
                            throw th;
                        }
                    } catch (Throwable th3) {
                        th = th3;
                        bArr = bytes;
                        if (bArr != null) {
                        }
                        throw th;
                    }
                }
                if (bytes != null) {
                    Arrays.fill(bytes, (byte) 0);
                }
            } catch (Exception e3) {
                e = e3;
                throw new OlmException(107, e.getMessage());
            }
        }
        return str2;
    }

    private void writeObject(ObjectOutputStream objectOutputStream) throws IOException {
        serialize(objectOutputStream);
    }

    private void readObject(ObjectInputStream objectInputStream) throws Exception {
        deserialize(objectInputStream);
    }

    /* access modifiers changed from: protected */
    @Override // org.matrix.olm.CommonSerializeUtils
    public byte[] serialize(byte[] bArr, StringBuffer stringBuffer) {
        if (stringBuffer == null) {
            Log.e(LOG_TAG, "## serialize(): invalid parameter - aErrorMsg=null");
        } else if (bArr == null) {
            stringBuffer.append("Invalid input parameters in serializeDataWithKey()");
        } else {
            stringBuffer.setLength(0);
            try {
                return serializeJni(bArr);
            } catch (Exception e) {
                Log.e(LOG_TAG, "## serialize() failed " + e.getMessage());
                stringBuffer.append(e.getMessage());
            }
        }
        return null;
    }

    /* access modifiers changed from: protected */
    @Override // org.matrix.olm.CommonSerializeUtils
    public void deserialize(byte[] bArr, byte[] bArr2) throws Exception {
        String str;
        if (bArr == null || bArr2 == null) {
            Log.e(LOG_TAG, "## deserialize(): invalid input parameters");
            str = "invalid input parameters";
        } else {
            try {
                this.mNativeId = deserializeJni(bArr, bArr2);
                str = null;
            } catch (Exception e) {
                Log.e(LOG_TAG, "## deserialize() failed " + e.getMessage());
                str = e.getMessage();
            }
        }
        if (!TextUtils.isEmpty(str)) {
            releaseAccount();
            throw new OlmException(101, str);
        }
    }

    public byte[] pickle(byte[] bArr, StringBuffer stringBuffer) {
        return serialize(bArr, stringBuffer);
    }

    public void unpickle(byte[] bArr, byte[] bArr2) throws Exception {
        deserialize(bArr, bArr2);
    }

    public void generateFallbackKey() throws OlmException {
        try {
            generateFallbackKeyJni();
        } catch (Exception e) {
            throw new OlmException(108, e.getMessage());
        }
    }

    public Map<String, Map<String, String>> fallbackKey() throws OlmException {
        JSONObject jSONObject;
        try {
            byte[] fallbackKeyJni = fallbackKeyJni();
            if (fallbackKeyJni != null) {
                try {
                    jSONObject = new JSONObject(new String(fallbackKeyJni, "UTF-8"));
                } catch (Exception e) {
                    Log.e(LOG_TAG, "## fallbackKey(): Exception - Msg=" + e.getMessage());
                }
            } else {
                Log.e(LOG_TAG, "## fallbackKey(): Failure - identityKeysJni()=null");
                jSONObject = null;
            }
            return OlmUtility.toStringMapMap(jSONObject);
        } catch (Exception e2) {
            throw new OlmException(109, e2.getMessage());
        }
    }
}
